@@ -1,7 +1,7 @@
 #######################################################################
 # arules - Mining Association Rules and Frequent Itemsets
 # Copyright (C) 2011-2015 Michael Hahsler, Christian Buchta,
-#			Bettina Gruen and Kurt Hornik
+# 			Bettina Gruen and Kurt Hornik
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -31,19 +31,19 @@
 #' @name APappearance-class
 #' @aliases APappearance
 #' @family mining algorithms
-#' 
-#' @section Objects from the Class: 
+#'
+#' @section Objects from the Class:
 #' If appearance restrictions are used, an
 #' appearance object will be created automatically within the
 #' [apriori()] function using the information in the named list of
 #' the function's `appearance` argument.  In this case, the item labels
 #' used in the list will be automatically matched against the items in the used
 #' [transactions].
-#' 
+#'
 #' Objects can also be created by calls of the form `new("APappearance",
 #' ...)`.  In this case, item IDs (column numbers of the transactions incidence
 #' matrix) have to be used instead of labels.
-#' 
+#'
 #' @slot labels character vectors giving the labels of the
 #' items which can appear in the specified place (rhs, lhs or both for rules
 #' and items for itemsets).  none specifies, that the items mentioned there
@@ -54,7 +54,7 @@
 #' `"both"`, `"lhs"`, `"rhs"`, `"none"`.  Specified the
 #' default appearance for all items not explicitly mentioned in the other
 #' elements of the list.  Leave unspecified and the code will guess the correct
-#' setting. 
+#' setting.
 #' @slot set used internally.
 #' @slot items used internally.
 #'
@@ -72,21 +72,27 @@
 #' data("Adult")
 #'
 #' ## find only frequent itemsets which do not contain small or large income
-#' is <- apriori(Adult, parameter = list(support= 0.1, target="frequent"),
-#'   appearance = list(none = c("income=small", "income=large")))
+#' is <- apriori(Adult,
+#'   parameter = list(support = 0.1, target = "frequent"),
+#'   appearance = list(none = c("income=small", "income=large"))
+#' )
 #' itemFrequency(items(is))["income=small"]
 #' itemFrequency(items(is))["income=large"]
 #'
 #' ## find itemsets that only contain small or large income, or young age
-#' is <- apriori(Adult, parameter = list(support= 0.1, target="frequent"),
-#'   appearance = list(items = c("income=small", "income=large", "age=Young")))
+#' is <- apriori(Adult,
+#'   parameter = list(support = 0.1, target = "frequent"),
+#'   appearance = list(items = c("income=small", "income=large", "age=Young"))
+#' )
 #' inspect(head(is))
 #'
 #' ## find only rules with income-related variables in the right-hand-side.
 #' incomeItems <- grep("^income=", itemLabels(Adult), value = TRUE)
 #' incomeItems
-#' rules <- apriori(Adult, parameter = list(support=0.2, confidence = 0.5),
-#'   appearance = list(rhs = incomeItems))
+#' rules <- apriori(Adult,
+#'   parameter = list(support = 0.2, confidence = 0.5),
+#'   appearance = list(rhs = incomeItems)
+#' )
 #' inspect(head(rules))
 #'
 #' ## Note: For more complicated restrictions you have to mine all rules/itemsets and
@@ -99,19 +105,18 @@ setClass(
     labels  = "character",
     default = "character"
   ),
-  
   prototype(
     set     = rep(0L, 5),
     items   = integer(),
     labels  = "",
     default = "both"
   ),
-  
   validity = function(object) {
-    if (!object@default %in% c("lhs", "rhs", "none", "both"))
+    if (!object@default %in% c("lhs", "rhs", "none", "both")) {
       return("Default value not specified correctly")
-    else if (!sum(object@set) == length(object@items))
+    } else if (!sum(object@set) == length(object@items)) {
       return("Slots 'set' and 'items' do not match")
+    }
     return(TRUE)
   }
 )
@@ -119,96 +124,114 @@ setClass(
 #' @rdname APappearance-class
 #' @name coercion-APappearance
 #' @section Coercions:
-#' 
+#'
 #' * `as("NULL", "APappearance")`
 #' * `as("list", "APappearance")`
 #'
-#' @aliases 
-#' coerce,NULL,APappearance-method 
+#' @aliases
+#' coerce,NULL,APappearance-method
 #' coerce,list,APappearance-method
 NULL
 
-setAs("NULL", "APappearance",
+setAs(
+  "NULL", "APappearance",
   function(from, to) {
     new(to)
-  })
+  }
+)
 
-setAs("list", "APappearance",
+setAs(
+  "list", "APappearance",
   function(from, to) {
-    if (!length(from))
+    if (!length(from)) {
       return(new("APappearance"))
-    
-    if (is.null(from$labels))
+    }
+
+    if (is.null(from$labels)) {
       stop("labels are missing")
-    
+    }
+
     args <- c("lhs", "rhs", "both", "none", "items")
     other <- c("default", "labels")
-    if (!all(names(from) %in% c(args, other)))
+    if (!all(names(from) %in% c(args, other))) {
       stop(paste(
         names(from)[!names(from) %in% c(args, other)],
         "is an unknown appearance indicator, use:",
         paste(args, collapse = " "),
         collapse = ", "
       ))
-    
+    }
+
     ## cannot set items and lhs, rhs or both
     if (!is.null(from$items) &&
-        (!is.null(from$lhs) ||
-            !is.null(from$rhs) || !is.null(from$both))) {
+      (!is.null(from$lhs) ||
+        !is.null(from$rhs) || !is.null(from$both))) {
       stop(
         "Cannot set appearance for mining association rules (lhs, rhs, both) and frequent itemset mining (items) at the same time!"
       )
     }
-    
+
     ## guess default
     if (is.null(from$default)) {
-      if (is.null(from$lhs)
-        && is.null(from$rhs))
+      if (is.null(from$lhs) &&
+        is.null(from$rhs)) {
         from$default <- "both"
-      if (!is.null(from$lhs)
-        && is.null(from$rhs))
+      }
+      if (!is.null(from$lhs) &&
+        is.null(from$rhs)) {
         from$default <- "rhs"
-      if (is.null(from$lhs)
-        && !is.null(from$rhs))
+      }
+      if (is.null(from$lhs) &&
+        !is.null(from$rhs)) {
         from$default <- "lhs"
-      
-      if (!is.null(from$rhs)
-        && !is.null(from$lhs))
+      }
+
+      if (!is.null(from$rhs) &&
+        !is.null(from$lhs)) {
         from$default <- "none"
-      
-      if (!is.null(from$both))
+      }
+
+      if (!is.null(from$both)) {
         from$default <- "none"
-      
+      }
+
       ## for itemsets
-      if (!is.null(from$items))
+      if (!is.null(from$items)) {
         from$default <- "none"
+      }
     }
-    
+
     set <- c()
     items <- c()
     for (i in seq_len(length(args))) {
       indicator <- from[[args[i]]]
-      if (is.null(indicator))
+      if (is.null(indicator)) {
         add_items <- NULL
-      else if (!all(indicator %in% from$labels))
+      } else if (!all(indicator %in% from$labels)) {
         stop(paste(indicator[!indicator %in% from$labels],
-          "is an unknown item label", collapse = ", "))
-      else
-        add_items <- unlist(sapply(indicator,
+          "is an unknown item label",
+          collapse = ", "
+        ))
+      } else {
+        add_items <- unlist(sapply(
+          indicator,
           function(x) {
             which(from$labels == x) - 1
-          }))
+          }
+        ))
+      }
       items <- c(items, add_items)
       set <- c(set, length(add_items))
     }
-    
+
     ## check for items in multiple positions (crashes C code!)
-    if (any(dup <- duplicated(items)))
+    if (any(dup <- duplicated(items))) {
       stop(
         "The following items cannot be specified in multiple appearance locations: ",
         paste(from$labels[items[dup] + 1L], collapse = ", ")
       )
-    
+    }
+
     ## check NA's
     return(
       new(
@@ -219,4 +242,5 @@ setAs("list", "APappearance",
         labels = from$labels
       )
     )
-  })
+  }
+)
