@@ -1,7 +1,7 @@
 #######################################################################
 # arules - Mining Association Rules and Frequent Itemsets
 # Copyright (C) 2011-2015 Michael Hahsler, Christian Buchta,
-#			Bettina Gruen and Kurt Hornik
+# 			Bettina Gruen and Kurt Hornik
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -33,16 +33,16 @@
 #' @family mining algorithms
 #'
 #' @section Available Slots by Subclass:
-#' 
-#' * `APcontrol`: 
+#'
+#' * `APcontrol`:
 #'   `r paste(paste0('\\code{', names(getSlots("APcontrol")), '}'), collapse = ", ")`
-#' 
-#' * `ECcontrol`: 
+#'
+#' * `ECcontrol`:
 #'   `r paste(paste0('\\code{', names(getSlots("ECcontrol")), '}'), collapse = ", ")`
-#' 
-#' @slot sort an integer scalar indicating how to 
+#'
+#' @slot sort an integer scalar indicating how to
 #'   sort items with respect to their frequency: (default: 2)
-#'   
+#'
 #'   *  1: ascending
 #'   * -1: descending
 #'   *  0: do not sort
@@ -50,38 +50,38 @@
 #'   * -2: descending with respect to transaction size sum
 #'
 #' @slot verbose a logical indicating whether to report progress
-#' 
+#'
 #' @slot filter a numeric scalar indicating how to
 #'   filter unused items from transactions (default: 0.1)
-#'   
+#'
 #'   * \eqn{=0}: do not filter items with respect to. usage in sets
 #'   * \eqn{<0}: fraction of removed items for filtering
 #'   * \eqn{>0}: take execution times ratio into account
-#'   
+#'
 #' @slot tree a logical indicating whether to
 #'   organize transactions as a prefix tree (default: `TRUE`)
-#'   
+#'
 #' @slot heap a logical indicating whether to
 #'   use heapsort instead of quicksort to sort the transactions
 #'   (default: `TRUE`)
-#'   
-#' @slot memopt a logical indicating whether to 
+#'
+#' @slot memopt a logical indicating whether to
 #'   minimize memory usage instead of maximize speed (default: `FALSE`)
-#'   
+#'
 #' @slot load a logical indicating whether to
 #'   load transactions into memory (default: `TRUE`)
-#'   
+#'
 #' @slot sparse a numeric value for the
 #'   threshold for sparse representation (default: 7)
 #'
-#' @section Objects from the Class: 
+#' @section Objects from the Class:
 #' A suitable default control object will be
 #' automatically created by the [apriori()] or the
 #' [eclat()] function. By specifying a named list (names equal to
 #' slots) as the `control` argument for [apriori()] or
 #' [eclat()], default values can be replaced with the values
-#' in the list.  
-#' 
+#' in the list.
+#'
 #' Objects can also be created via coercion.
 #'
 #' @author Michael Hahsler and Bettina Gruen
@@ -92,14 +92,16 @@
 #' @aliases initialize,AScontrol-method show,AScontrol-method
 setClass(
   "AScontrol",
-  representation(sort    = "integer",
-    verbose = "logical"),
-  
-  prototype(verbose = TRUE,
-    sort    = 2L),
-  
+  representation(
+    sort = "integer",
+    verbose = "logical"
+  ),
+  prototype(
+    verbose = TRUE,
+    sort = 2L
+  ),
   validity = function(object) {
-    if (object@sort > 2 | object@sort < -2)
+    if (object@sort > 2 | object@sort < -2) {
       return(
         paste(
           "sort =",
@@ -109,35 +111,46 @@ setClass(
           "-2: descending w.r.t. transaction size sum"
         )
       )
-    else
+    } else {
       return(TRUE)
+    }
   }
 )
 
-setMethod("initialize", "AScontrol",
+setMethod(
+  "initialize", "AScontrol",
   function(.Object, sort, ...) {
     if (!missing(sort)) {
-      if (sort - as.integer(sort))
-        stop("sort = ", sort,
-          " can not be coerced to integer without error.")
+      if (sort - as.integer(sort)) {
+        stop(
+          "sort = ", sort,
+          " can not be coerced to integer without error."
+        )
+      }
       sort <- as.integer(sort)
       .Object <- callNextMethod(.Object, sort = sort, ...)
-    }
-    else
+    } else {
       .Object <- callNextMethod(.Object, ...)
+    }
     .Object
-  })
+  }
+)
 
-setMethod("show", signature(object = "AScontrol"),
+setMethod(
+  "show", signature(object = "AScontrol"),
   function(object) {
     print(data.frame(
       sapply(slotNames(object),
-        function(x)
-          slot(object, x), simplify = FALSE),
+        function(x) {
+          slot(object, x)
+        },
+        simplify = FALSE
+      ),
       row.names = ""
     ))
     invisible(NULL)
-  })
+  }
+)
 
 #' @rdname AScontrol-classes
 #' @aliases APcontrol
@@ -150,8 +163,7 @@ setClass(
     memopt  = "logical",
     load    = "logical"
   ),
-  contains    = "AScontrol",
-  
+  contains = "AScontrol",
   prototype(
     new("AScontrol"),
     filter  = 0.1,
@@ -161,12 +173,12 @@ setClass(
     memopt  = FALSE,
     load    = TRUE
   ),
-  
   validity = function(object) {
-    if (object@filter > 1 || object@filter < -1)
+    if (object@filter > 1 || object@filter < -1) {
       return(paste("filter =", object@filter, "is not in [-1,1]"))
-    else
+    } else {
       return(TRUE)
+    }
   }
 )
 
@@ -176,10 +188,10 @@ setClass(
   "ECcontrol",
   representation(sparse = "numeric"),
   contains = "AScontrol",
-  
   prototype(new("AScontrol"),
     sparse  = 7,
-    sort    = -2L)
+    sort    = -2L
+  )
 )
 
 #' @rdname AScontrol-classes
@@ -191,26 +203,31 @@ setClass(
 #' * `as("NULL", "ECcontrol")`
 #' * `as("list", "ECcontrol")`
 #'
-#' @aliases 
-#'   coerce,NULL,APcontrol-method 
+#' @aliases
+#'   coerce,NULL,APcontrol-method
 #'   coerce,list,APcontrol-method
-#'   coerce,NULL,ECcontrol-method 
+#'   coerce,NULL,ECcontrol-method
 #'   coerce,list,ECcontrol-method
 #'
 
-setAs("NULL", "APcontrol",
+setAs(
+  "NULL", "APcontrol",
   function(from, to) {
     new(to)
-  })
+  }
+)
 
-setAs("list", "APcontrol", function(from, to)
-  .list2object(from, to))
+setAs("list", "APcontrol", function(from, to) {
+  .list2object(from, to)
+})
 
-setAs("NULL", "ECcontrol",
+setAs(
+  "NULL", "ECcontrol",
   function(from, to) {
     new(to)
-  })
-
-setAs("list", "ECcontrol", function(from, to)
-  .list2object(from, to))
+  }
+)
 
+setAs("list", "ECcontrol", function(from, to) {
+  .list2object(from, to)
+})
