@@ -1,7 +1,7 @@
 #######################################################################
 # arules - Mining Association Rules and Frequent Itemsets
 # Copyright (C) 2011-2015 Michael Hahsler, Christian Buchta,
-#			Bettina Gruen and Kurt Hornik
+# 			Bettina Gruen and Kurt Hornik
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -44,12 +44,12 @@
 #' al (2014) propose to use the confidence interval (CI) of the odds ratio (OR)
 #' of rules to define redundancy. A more specific rule is redundant if it does
 #' not provide a significantly higher OR than any more general rule. Using
-#' confidence intervals as error bounds, a more specific rule is 
-#' defined as redundant if its OR CI overlaps with the CI of any more general 
+#' confidence intervals as error bounds, a more specific rule is
+#' defined as redundant if its OR CI overlaps with the CI of any more general
 #' rule. This type of redundancy detection removes more rules
 #' than improvement since it takes differences in counts due to randomness in
 #' the dataset into account.
-#' 
+#'
 #' The odds ratio and the CI are based on counts which can be zero and which
 #' leads to numerical problems. In addition to the method described by Li et al
 #' (2014), we use additive smoothing (Laplace smoothing) to alleviate this
@@ -57,15 +57,15 @@
 #' [confint()]). A different pseudocount (smoothing parameter) can be
 #' defined using the additional parameter `smoothCounts`. Smoothing can be
 #' disabled using `smoothCounts = 0`.
-#' 
-#' **Warning:** This approach of redundancy checking is flawed since rules with 
+#'
+#' **Warning:** This approach of redundancy checking is flawed since rules with
 #' non-overlapping CIs are
-#' non-redundant (same result as for a 2-sample t-test), but overlapping CIs do 
+#' non-redundant (same result as for a 2-sample t-test), but overlapping CIs do
 #' not automatically mean that there is no significant difference between the
 #' two measures which leads to a higher type II error. At the same time,
-#' multiple comparisons are performed leading to an increased type I error. If 
-#' we are more worried about missing important rules, then the type II error 
-#' is more concerning. 
+#' multiple comparisons are performed leading to an increased type I error. If
+#' we are more worried about missing important rules, then the type II error
+#' is more concerning.
 #'
 #' Confidence interval-based redundancy checks can also be used for other
 #' measures with a confidence interval like confidence (see
@@ -74,7 +74,7 @@
 #' @family postprocessing
 #' @family associations functions
 #' @family interest measures
-#' 
+#'
 #' @param x a set of rules.
 #' @param measure measure used to check for redundancy.
 #' @param confint should confidence intervals be used to the redundancy check?
@@ -102,8 +102,10 @@
 #' data("Income")
 #'
 #' ## mine some rules with the consequent "language in home=english"
-#' rules <- apriori(Income, parameter = list(support = 0.5),
-#'   appearance = list(rhs = "language in home=english"))
+#' rules <- apriori(Income,
+#'   parameter = list(support = 0.5),
+#'   appearance = list(rhs = "language in home=english")
+#' )
 #'
 #' ## for better comparison we add Bayado's improvement and sort by improvement
 #' quality(rules)$improvement <- interestMeasure(rules, measure = "improvement")
@@ -118,41 +120,53 @@
 #'
 #' ## use non-overlapping confidence intervals for the confidence measure instead
 #' ## Note: fewer rules have a significantly higher confidence
-#' inspect(rules[!is.redundant(rules, measure = "confidence",
-#'   confint = TRUE, level = 0.95)])
+#' inspect(rules[!is.redundant(rules,
+#'   measure = "confidence",
+#'   confint = TRUE, level = 0.95
+#' )])
 #'
 #' ## find non-redundant rules using improvement of the odds ratio.
-#' quality(rules)$oddsRatio <-  interestMeasure(rules, measure = "oddsRatio", smoothCounts = .5)
+#' quality(rules)$oddsRatio <- interestMeasure(rules, measure = "oddsRatio", smoothCounts = .5)
 #' inspect(rules[!is.redundant(rules, measure = "oddsRatio")])
 #'
 #' ## use the confidence interval for the odds ratio.
 #' ## We see that no rule has a significantly better odds ratio than the most general rule.
-#' inspect(rules[!is.redundant(rules, measure = "oddsRatio",
-#'   confint = TRUE, level = 0.95)])
+#' inspect(rules[!is.redundant(rules,
+#'   measure = "oddsRatio",
+#'   confint = TRUE, level = 0.95
+#' )])
 #'
 #' ##  use the confidence interval for lift
-#' inspect(rules[!is.redundant(rules, measure = "lift",
-#'   confint = TRUE, level = 0.95)])
+#' inspect(rules[!is.redundant(rules,
+#'   measure = "lift",
+#'   confint = TRUE, level = 0.95
+#' )])
 #'
-setGeneric("is.redundant",
-  function(x, ...)
-    standardGeneric("is.redundant"))
+setGeneric(
+  "is.redundant",
+  function(x, ...) {
+    standardGeneric("is.redundant")
+  }
+)
 
 #' @rdname is.redundant
-setMethod("is.redundant", signature(x = "rules"),
-  function(x,
-    measure = "confidence",
-    confint = FALSE,
-    level = 0.95,
-    smoothCounts = 1,
-    ...) {
-    if (confint)
+setMethod(
+  "is.redundant", signature(x = "rules"),
+  function(
+      x,
+      measure = "confidence",
+      confint = FALSE,
+      level = 0.95,
+      smoothCounts = 1,
+      ...) {
+    if (confint) {
       .improvementCI(x,
         measure = measure,
         level = level,
         smoothCounts = smoothCounts,
-        ...) <= 0
-    else
+        ...
+      ) <= 0
+    } else {
       interestMeasure(
         x,
         measure = "improvement",
@@ -160,37 +174,41 @@ setMethod("is.redundant", signature(x = "rules"),
         smoothCounts = smoothCounts,
         ...
       ) <= 0
-  })
+    }
+  }
+)
 
 # Is the supersets oddsRatio sign. larger than all its subsets?
 # I.e., the superset's lower bound needs to be larger than the subset's upper bound
 
-.improvementCI <- function(x,
-  measure,
-  level = 0.95,
-  smoothCounts = 0.5,
-  ...) {
+.improvementCI <- function(
+    x,
+    measure,
+    level = 0.95,
+    smoothCounts = 0.5,
+    ...) {
   q <- confint(x,
     measure,
     level = level,
     smoothCounts = smoothCounts,
-    ...)
-  
+    ...
+  )
+
   # q is a data.frame with LL and UL
   imp <- numeric(length(x))
-  
+
   ### do it by unique rhs
   rr <- .Call(R_pnindex, rhs(x)@data, NULL, FALSE)
-  
+
   for (r in unique(rr)) {
     pos <- which(rr == r)
-    
+
     ### FALSE is for verbose
     qsubmax <-
       .Call(R_pnmax, lhs(x[pos])@data, q[pos, "UL"], FALSE)
-    
+
     imp[pos] <- q[pos, "LL"] - qsubmax
   }
-  
+
   imp
 }
