@@ -1,7 +1,7 @@
 #######################################################################
 # arules - Mining Association Rules and Frequent Itemsets
 # Copyright (C) 2011-2015 Michael Hahsler, Christian Buchta,
-#			Bettina Gruen and Kurt Hornik
+# 			Bettina Gruen and Kurt Hornik
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -37,12 +37,12 @@
 #' @param x,y associations or itemMatrix objects. If `y = NULL`, the super
 #' or subset structure within set `x` is calculated.
 #' @param proper a logical indicating if all or just proper super or subsets.
-#' @param sparse a logical indicating if a sparse [Matrix::ngCMatrix-class] 
-#' rather than a dense logical matrix should be returned. 
+#' @param sparse a logical indicating if a sparse [Matrix::ngCMatrix-class]
+#' rather than a dense logical matrix should be returned.
 #' Sparse computation requires a
 #' significantly smaller amount of memory and is much faster for large sets.
 #' @param ... currently unused.
-#' @return returns a logical matrix or a sparse [Matrix::ngCMatrix-class] 
+#' @return returns a logical matrix or a sparse [Matrix::ngCMatrix-class]
 #' with `length(x)` rows and `length(y)` columns.
 #' Each logical row vector represents which elements in `y` are supersets
 #' (subsets) of the corresponding element in `x`.  If either `x` or
@@ -56,106 +56,140 @@
 #' ### find the supersets of each itemset in set
 #' is.superset(set, set)
 #' is.superset(set, set, sparse = FALSE)
-setGeneric("is.superset",
-  function(x,
-    y = NULL,
-    proper = FALSE,
-    sparse = TRUE,
-    ...)
-    standardGeneric("is.superset"))
+setGeneric(
+  "is.superset",
+  function(
+      x,
+      y = NULL,
+      proper = FALSE,
+      sparse = TRUE,
+      ...) {
+    standardGeneric("is.superset")
+  }
+)
 
 #' @rdname is.superset
-setGeneric("is.subset",
-  function(x,
-    y = NULL,
-    proper = FALSE,
-    sparse = TRUE,
-    ...)
-    standardGeneric("is.subset"))
+setGeneric(
+  "is.subset",
+  function(
+      x,
+      y = NULL,
+      proper = FALSE,
+      sparse = TRUE,
+      ...) {
+    standardGeneric("is.subset")
+  }
+)
 
 #' @rdname is.superset
-setMethod("is.superset", signature(x = "itemMatrix"),
-  function(x,
-    y = NULL,
-    proper = FALSE,
-    sparse = TRUE)
-    if (is.null(y))
+setMethod(
+  "is.superset", signature(x = "itemMatrix"),
+  function(
+      x,
+      y = NULL,
+      proper = FALSE,
+      sparse = TRUE) {
+    if (is.null(y)) {
       t(is.subset(x, NULL, proper, sparse))
-  else
-    t(is.subset(y, x, proper, sparse)))
+    } else {
+      t(is.subset(y, x, proper, sparse))
+    }
+  }
+)
 
 #' @rdname is.superset
-setMethod("is.superset", signature(x = "associations"),
-  function (x,
-    y = NULL,
-    proper = FALSE,
-    sparse = TRUE)
-    if (is.null(y))
+setMethod(
+  "is.superset", signature(x = "associations"),
+  function(
+      x,
+      y = NULL,
+      proper = FALSE,
+      sparse = TRUE) {
+    if (is.null(y)) {
       t(is.subset(x, NULL, proper, sparse))
-  else
-    t(is.subset(y, x, proper, sparse)))
+    } else {
+      t(is.subset(y, x, proper, sparse))
+    }
+  }
+)
 
 ## this takes about 3 times the memory but is very fast!
 ## I suspect internally it always uses a lot of memory.
 
 #' @rdname is.superset
-setMethod("is.subset", signature(x = "itemMatrix"),
-  function(x,
-    y = NULL,
-    proper = FALSE,
-    sparse = TRUE) {
-    if (length(x) == 0 || (!is.null(y) && length(y) == 0))
+setMethod(
+  "is.subset", signature(x = "itemMatrix"),
+  function(
+      x,
+      y = NULL,
+      proper = FALSE,
+      sparse = TRUE) {
+    if (length(x) == 0 || (!is.null(y) && length(y) == 0)) {
       return(logical(0))
-    
+    }
+
     ## y needs to be itemMatrix and x has to conform!
     if (!is.null(y)) {
-      if (is(y, "associations"))
+      if (is(y, "associations")) {
         y <- items(y)
-      if (!is(y, "itemMatrix"))
+      }
+      if (!is(y, "itemMatrix")) {
         stop("y needs to be an itemMatrix.")
+      }
       il <- union(itemLabels(x), itemLabels(y))
       x <- recode(x, itemLabels = il)
       y <- recode(y, itemLabels = il)
     }
-    
-    if (sparse)
+
+    if (sparse) {
       return(.is.subset_sparse(x, y, proper))
-    
-    if (is.null(y))
+    }
+
+    if (is.null(y)) {
       m <- .Call(R_crosstab_ngCMatrix, x@data, NULL, FALSE)
-    else
+    } else {
       m <- .Call(R_crosstab_ngCMatrix, x@data, y@data, FALSE)
-    
+    }
+
     m <- m == size(x)
-    
-    if (proper == TRUE)
-      if (is.null(y))
+
+    if (proper == TRUE) {
+      if (is.null(y)) {
         m <- m & outer(size(x), size(x), "<")
-    else
-      m <- m & outer(size(x), size(y), "<")
-    
+      } else {
+        m <- m & outer(size(x), size(y), "<")
+      }
+    }
+
     rownames(m) <- labels(x)
-    if (is.null(y))
+    if (is.null(y)) {
       colnames(m) <- labels(x)
-    else
+    } else {
       colnames(m) <- labels(y)
-    
+    }
+
     m
-  })
+  }
+)
 
 #' @rdname is.superset
-setMethod("is.subset", signature(x = "associations"),
-  function(x,
-    y = NULL,
-    proper = FALSE,
-    sparse = TRUE)
-    is.subset(items(x), y, proper, sparse))
+setMethod(
+  "is.subset", signature(x = "associations"),
+  function(
+      x,
+      y = NULL,
+      proper = FALSE,
+      sparse = TRUE) {
+    is.subset(items(x), y, proper, sparse)
+  }
+)
 
 ### use tidlist intersection
 .is.subset_sparse <- function(x, y = NULL, proper = FALSE) {
-  if (is.null(y))
+  if (is.null(y)) {
     y <- x
-  
+  }
+
   p <- as.integer(rep(0, x@data@Dim[2] + 1))
   i <- .Call(
     R_is_subset,
@@ -169,7 +203,7 @@ setMethod("is.subset", signature(x = "associations"),
     p,
     PACKAGE = "arules"
   )
-  
+
   t(new(
     "ngCMatrix",
     p = p,
@@ -184,12 +218,13 @@ setMethod("is.subset", signature(x = "associations"),
 .list2ngCMatrix <- function(from, max = NULL) {
   from <- lapply(from, sort)
   p <- cumsum(sapply(from, length))
-  
+
   i <- as.integer(unlist(from, use.names = FALSE))
-  
-  if (is.null(max))
+
+  if (is.null(max)) {
     max <- max(i)
-  
+  }
+
   t(new(
     "ngCMatrix",
     p   = c(0L, p),
